@@ -2,8 +2,6 @@
 #'
 #' Get record details from CTS, see \url{http://cts.fiehnlab.ucdavis.edu/}
 #' @import jsonlite
-#' @importFrom stats rgamma
-#' @importFrom stats setNames
 #' @param query character; InChIkey.
 #' @param from character; currently only accepts "inchikey".
 #' @param verbose logical; should a verbose output be printed on the console?
@@ -51,7 +49,7 @@ cts_compinfo <- function(query, from = "inchikey", verbose = TRUE, inchikey){
     }
     baseurl <- "http://cts.fiehnlab.ucdavis.edu/service/compound"
     qurl <- paste0(baseurl, '/', query)
-    Sys.sleep(stats::rgamma(1, shape = 15, scale = 1/10))
+    webchem_sleep(type = 'API')
     out <- try(httr::RETRY("GET",
                            qurl,
                            httr::user_agent(webchem_url()),
@@ -71,7 +69,7 @@ cts_compinfo <- function(query, from = "inchikey", verbose = TRUE, inchikey){
     }
   }
   out <- lapply(query, foo, verbose = verbose)
-  out <- setNames(out, query)
+  names(out) <- query
   class(out) <- c('cts_compinfo','list')
   return(out)
 }
@@ -80,10 +78,8 @@ cts_compinfo <- function(query, from = "inchikey", verbose = TRUE, inchikey){
 #' Convert Ids using Chemical Translation Service (CTS)
 #'
 #' Convert Ids using Chemical Translation Service (CTS), see \url{http://cts.fiehnlab.ucdavis.edu/}
-#' @import RCurl jsonlite
+#' @import jsonlite
 #' @importFrom utils URLencode
-#' @importFrom stats rgamma
-#' @importFrom stats setNames
 #' @param query character; query ID.
 #' @param from character; type of query ID, e.g. \code{'Chemical Name'} , \code{'InChIKey'},
 #'  \code{'PubChem CID'}, \code{'ChemSpider'}, \code{'CAS'}.
@@ -166,7 +162,7 @@ cts_convert <- function(query,
     to <- URLencode(to, reserved = TRUE)
     baseurl <- "http://cts.fiehnlab.ucdavis.edu/service/convert"
     qurl <- paste0(baseurl, '/', from, '/', to, '/', query)
-    Sys.sleep(stats::rgamma(1, shape = 15, scale = 1/10))
+    webchem_sleep(type = 'API')
     res <- try(httr::RETRY("GET",
                            qurl,
                            httr::user_agent(webchem_url()),
@@ -192,7 +188,7 @@ cts_convert <- function(query,
     }
   }
   out <- lapply(query, foo, from = from, to = to, first = first, verbose = verbose)
-  out <- setNames(out, query)
+  names(out) <- query
   return(out)
 }
 
