@@ -150,11 +150,9 @@ test_that("pc_sect()", {
   a <- pc_sect(c(311, 176, 1118, "balloon", NA), "pKa")
   expect_s3_class(a, c("tbl_df", "tbl", "data.frame"))
   expect_equal(mean(c("Citric acid", "Acetic acid", NA) %in% a$Name), 1)
-  expect_equal(mean(c("2.79", "pKa3 6.43 (25 °)", "4.76 (at 25 °C)",
-                      "pKa 4.78 (25 °)", NA) %in% a$Result), 1)
-  expect_equal(mean(c("DrugBank", "FooDB", NA) %in% a$SourceName), 1)
-  expect_equal(mean(c("DB04272", "FDB012586", "DB03166","FDB008299", NA) %in%
-                      a$SourceID), 1)
+  expect_equal(mean(c("2.79", "4.76 (at 25 °C)", NA) %in% a$Result), 1)
+  expect_equal(mean(c("DrugBank", NA) %in% a$SourceName), 1)
+  expect_equal(mean(c("DB04272", "DB03166", NA) %in% a$SourceID), 1)
   b <- pc_sect(2231, "depositor-supplied synonyms", "substance")
   expect_s3_class(b, c("tbl_df", "tbl", "data.frame"))
   expect_equal(names(b), c("SID", "Name", "Result", "SourceName", "SourceID"))
